#!/bin/ash

/usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_home_rx_bytes
/usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_home_tx_bytes
/usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_roaming_rx_bytes
/usr/bin/gconftool-2 --unset /system/osso/connectivity/network_type/GPRS/gprs_roaming_tx_bytes
/usr/bin/gconftool-2 --set /system/osso/connectivity/network_type/GPRS/gprs_home_reset_time --type=string "$(date +%s)"
/usr/bin/gconftool-2 --set /system/osso/connectivity/network_type/GPRS/gprs_roaming_reset_time --type=string "$(date +%s)"

